summaryrefslogtreecommitdiffstats
path: root/lib/kross/main/mainmodule.h
diff options
context:
space:
mode:
Diffstat (limited to 'lib/kross/main/mainmodule.h')
-rw-r--r--lib/kross/main/mainmodule.h46
1 files changed, 23 insertions, 23 deletions
diff --git a/lib/kross/main/mainmodule.h b/lib/kross/main/mainmodule.h
index 116e098d..bc7efc45 100644
--- a/lib/kross/main/mainmodule.h
+++ b/lib/kross/main/mainmodule.h
@@ -29,9 +29,9 @@
#include "../api/qtobject.h"
#include "../api/eventaction.h"
-#include <qstring.h>
-#include <qvariant.h>
-#include <qobject.h>
+#include <tqstring.h>
+#include <tqvariant.h>
+#include <tqobject.h>
#include <ksharedptr.h>
#include <kaction.h>
@@ -65,7 +65,7 @@ namespace Kross { namespace Api {
* the \a ScriptContainer instances are accessible
* by there \a ScriptContainer::getName() name.
*/
- explicit MainModule(const QString& name);
+ explicit MainModule(const TQString& name);
/**
* Destructor.
@@ -73,7 +73,7 @@ namespace Kross { namespace Api {
virtual ~MainModule();
/// \see Kross::Api::Object::getClassName()
- virtual const QString getClassName() const;
+ virtual const TQString getClassName() const;
/**
* \return true if the script throwed an exception
@@ -101,54 +101,54 @@ namespace Kross { namespace Api {
*
* \return true if child exists else false.
*/
- bool hasChild(const QString& name) const;
+ bool hasChild(const TQString& name) const;
#endif
/**
- * Add a Qt signal to the \a Module by creating
+ * Add a TQt signal to the \a Module by creating
* an \a EventSignal for it.
*
* \param name the name the \a EventSignal is
* reachable as
* \param sender the QObject instance which
* is the sender of the \p signal
- * \param signal the Qt signal macro the \p sender
+ * \param signal the TQt signal macro the \p sender
* emits to call the \a EventSignal
* \return the newly added \a EventSignal instance
* which is now a child of this \a MainModule
*/
- EventSignal::Ptr addSignal(const QString& name, QObject* sender, QCString signal);
+ EventSignal::Ptr addSignal(const TQString& name, TQObject* sender, TQCString signal);
/**
- * Add a Qt slot to the \a Module by creating
+ * Add a TQt slot to the \a Module by creating
* an \a EventSlot for it.
*
* \param name the name the \a EventSlot is
* reachable as
* \param receiver the QObject instance which
* is the receiver of the \p signal
- * \param slot the Qt slot macro of the \p receiver
+ * \param slot the TQt slot macro of the \p receiver
* to invoke if the \a EventSlot got called.
* \return the newly added \a EventSlot instance
* which is now a child of this \a MainModule
*/
- EventSlot::Ptr addSlot(const QString& name, QObject* receiver, QCString slot);
+ EventSlot::Ptr addSlot(const TQString& name, TQObject* receiver, TQCString slot);
/**
* Add a \a QObject to the eventcollection. All
* signals and slots the QObject has will be
* added to a new \a EventCollection instance
* which is child of this \a EventCollection
* instance.
*
* \param object the QObject instance that should
* be added to this \a MainModule
* \param name the name under which this QObject instance
* should be registered as
* \return the newly added \a QtObject instance
* which is now a child of this \a MainModule
*/
- QtObject::Ptr addQObject(QObject* object, const QString& name = QString::null);
+ QtObject::Ptr addTQObject(TQObject* object, const TQString& name = TQString());
/**
* Add a \a KAction to the eventcollection. The
@@ -163,12 +163,12 @@ namespace Kross { namespace Api {
*
* \todo check \a name dox.
*/
- EventAction::Ptr addKAction(KAction* action, const QString& name = QString::null);
+ EventAction::Ptr addKAction(KAction* action, const TQString& name = TQString());
- //typedef QValueList<Callable::Ptr> EventList;
+ //typedef TQValueList<Callable::Ptr> EventList;
//EventList getEvents();
- //const QString& serializeToXML();
- //void unserializeFromXML(const QString& xml);
+ //const TQString& serializeToXML();
+ //void unserializeFromXML(const TQString& xml);
private:
/// Private d-pointer class.
@@ -101,54 +101,54 @@ namespace Kross { namespace Api {
* \param name the name the \a EventSignal is
* reachable as
- * \param sender the QObject instance which
+ * \param sender the TQObject instance which
* is the sender of the \p signal
@@ -101,54 +101,54 @@ namespace Kross { namespace Api {
* \param name the name the \a EventSlot is
* reachable as
- * \param receiver the QObject instance which
+ * \param receiver the TQObject instance which
* is the receiver of the \p signal
@@ -101,54 +101,54 @@ namespace Kross { namespace Api {
/**
- * Add a \a QObject to the eventcollection. All
- * signals and slots the QObject has will be
+ * Add a \a TQObject to the eventcollection. All
+ * signals and slots the TQObject has will be
* added to a new \a EventCollection instance
* which is child of this \a EventCollection
@@ -101,54 +101,54 @@ namespace Kross { namespace Api {
* instance.
*
- * \param object the QObject instance that should
+ * \param object the TQObject instance that should
* be added to this \a MainModule
@@ -101,54 +101,54 @@ namespace Kross { namespace Api {
* be added to this \a MainModule
- * \param name the name under which this QObject instance
+ * \param name the name under which this TQObject instance
* should be registered as
* \return the newly added \a QtObject instance